@@ -1,5 +1,5 @@
 package CPAN::Testers::Reports::Counts;
-$CPAN::Testers::Reports::Counts::VERSION = '0.04';
+$CPAN::Testers::Reports::Counts::VERSION = '0.05';
 # ABSTRACT: counts of CPAN Testers reports by month or year
 use strict;
 use warnings;
@@ -83,9 +83,9 @@ CPAN::Testers::Reports::Count - counts of CPAN Testers reports by month or year
 =head1 SYNOPSIS
 
  use CPAN::Testers::Reports::Counts ':all';
- 
+
  $counts = reports_counts_by_year();
- 
+
  foreach my $year (sort keys %$counts) {
      print "$year:\n";
      foreach my $category (qw(REPORTS PASS FAIL NA UNKNOWN)) {
@@ -152,7 +152,7 @@ L<CPAN::Testers::Data::Generator> - a module used to download and summarize CPAN
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/CPAN-Testers-Reports-Counts>
+L<https://github.com/neilb/CPAN-Testers-Reports-Counts>
 
 =head1 AUTHOR
 
